@@ -18,12 +18,13 @@ class SentryPostbox : public QObject
 public:
     explicit SentryPostbox(const QString &applicationName, std::shared_ptr<SentryConnection> connection, QObject *parent = nullptr);
 
-    void addEventPayload(const SentryEvent &event);
+    void addEventPayload(const QJsonDocument &document);
     void addUserFeedback(const QString &feedbackString);
 
     void deliver();
     bool hasDelivered() const;
     bool isReadyToDeliver() const;
+    [[nodiscard]] QString eventId() const;
 
 Q_SIGNALS:
     void hasDeliveredChanged();
