@@ -21,8 +21,6 @@ public:
 private Q_SLOTS:
     void btParserUsefulnessTest_data();
     void btParserUsefulnessTest();
-    void btParserFunctionsTest_data();
-    void btParserFunctionsTest();
     void btParserBenchmark_data();
     void btParserBenchmark();
     void btParserCompositorCrashTest_data();
